
C
C  --------------------------------------------------------------------
C        PROGRAM VYPAR - operations with photometric data archives
C
C                         Author:       Jiri Horn
C
C             Modifications after 1993 made by Petr Harmanec
C
C           Release 9.2                         April 26, 2016          REL.9.2
C
C                          RELEASED as VYPAR.F
C
C
C        (calculates rms per 1 observation of unit weight)
C  --------------------------------------------------------------------
C
C         (Starting with Release 2.2, the modifications
C             have been carried out by Petr Harmanec)
C
C     Rel. 2.2 has corrected an error in ASCII to BIN transfer of HJDs
C
C     Rel. 2.3 has corrected calculation of normal points in situations
C     when several identical values of a magnitude were averaged,
C     previous releases failed on a DSQRT error
C
C     Rel. 3.0 has corrected a hidden error and allows now
C              to create a copy of ``Table of objects" to which
C              improved UBV magnitudes from a user-defined data archive
C              for selected types of objects (1-9) are copied
C
C     Rel. 4.0 has increased the allowed maximum of different stars
C              to 2000 (from previous 750)
C
C     Rel. 5.0 can read also UBV.TAB tables with more than 999 stars
C              if requested in the first line before the number of colours
C
C     Rel. 6.0 puts newly created Table of objects into file specified
C              by the user in the control file (it used to be ft78)
C              Now the output of the new Table with values from
C              all-sky archive works also for Table with more than 999 objects
C
C     Rel. 7.0 A substantial change: All input/output operations
C              are no formatted; unformatted form of the archives
C              is abandoned because of incompability of unformatted
C              records for different platforms and compilers!
C
C              Another important change is the change of the fixed
C              format used to permit station numbers larger than 99
C              This also led to the need to change the format of the control
C              file for selection of data from only one specific station.
C
C     Rel. 8.0 Another important change: Modified to treat output archives
C              from HEC22 rel. 18 on: Table of objects for 4-colour
C              observations now contains third index (mag(3)-mag(4))
C              (u-v instead of v in the case of Stromgren photometry)
C              or index (mag(1)-mag(4)) (i.e. V-R) in the case of
C              UBVR photometry.  To distinguish these two options,
C              parameter MSYS is read with the first control record,
C              must be set to 1 in case of UBVR, remains zero or blank
C              otherwise.
C
C     Rel. 8.1 modified to deal also with BVR photometry, print correct
C              headers and V-R index whenever appropriate

C     Rel. 9.0 The parts of the program containing earlier regimes
C              1, 7 and 8 (sorting and to and from ASCII conversions
C              were removed from the program
C
C     Rel. 9.1 Enables output of all considered colour indices          REL.9.1
C                      First released March 10, 2016                    REL.9.1
C              Remaining bugs hopefully identified and corrected        REL.9.1
C
C     Rel. 9.2 Error in the print of rms errors in the list of stars    REL.9.2
C              from UBV archives hopefully corrected                    REL.9.2
C              Print of stations > 99 in output for averaged data       REL.9.2
C
C              Labels from 7001 are used
C
C              ID=-1: all-sky archive; ID=-2: differential archive
C  ---------------------------------------------------------------------
C
      CHARACTER*12 INP,INP0,INP1,INP2,INP3,OUTP
      CHARACTER*4 NAZEV,JMENO,JMENO1                                    REL.9.1
      CHARACTER*4 IHD/'HD  '/,IALL/'ALL '/,ICH/'CHAN'/
      REAL*8 OD,DO,P,PER,T0
      INTEGER*4 IZT(10),INTAB
      REAL*4 V(7)
      INTEGER*4 HD
C
      LOGICAL exist
      CHARACTER line
C
      COMMON /C1/NAZEV(6),ID,NHV,NM,HJDMIN,HJDMAX,HD(2000),D1(2000),
     *           D2(2000),NM1(2000),NM2(2000)
      INTEGER*4 OUT
      COMMON /CC/OD,DO,KLIC,IN,OUT,IN2,JMENO(5),                        REL 7.0
     *        KB,KAP,KCS,KQ,KOBS,KONEC,IQ,IAP,ICS,IEX,IOBS,NOTAB
C
      CHARACTER*4 OBSR
      COMMON /CO/NOR,OBSR(400)
      COMMON /CT/INP,INP1,OUTP,NCOL
      COMMON /TABST/INTAB
      COMMON /SYST/MSYS                                                 REL.8
C
C
C
C
C
C
C
 1000 FORMAT (4I5,3A4,F8.0,4F10.0)
 1003 FORMAT (20X,3A4,F8.0,4F10.0)
 1004 FORMAT (20X,A2,I10,F8.0,4F10.0)
 1005 FORMAT (30X,10I1)
 9001 FORMAT (A12)
 9002 FORMAT (I1,I4,I5,A12)                                             REL.8
C
C
      PRINT *,'Input file of control records?'
      READ (*,'(A)') INP3
      print *,   inp3
      OPEN(UNIT=5,FILE=INP3,STATUS='OLD')
       READ(5,9002) NOTAB,NCOL,MSYS,INP2                                REL.8
       IF (NCOL.EQ.0) NCOL=3
       IF (MSYS.EQ.0) MSYS=3
       PRINT *,' Number of colours processed :',NCOL
       IF(INP2.EQ.'            '.AND.NCOL.EQ.3)INP2='ubv.tab'
       IF(INP2.EQ.'            '.AND.NCOL.EQ.4)INP2='uvby.TAB'
      INTAB=77
      OPEN(UNIT=INTAB,FILE=INP2,STATUS='OLD')
       PRINT *,' Input table of objects (standard values) : ',INP2
C
C
C      OPEN(UNIT=99,FORM='UNFORMATTED')                                 REL 7.0
C      OPEN(UNIT=98,FORM='UNFORMATTED')                                 REL 7.0
C
      CALL TAB2(INTAB)
      INP0='            '
      IN0=0
      NOR=0
      OUTP='VYPAR.OUT'
C
C
C
    1 READ (5,1000,END=99) KLIC,IN,OUT,IN2,(JMENO(K),K=1,3),P,          
     *                     OD,DO,PER,T0
C
C
      GO TO (801,4,5,6,6,6,802,803), KLIC
      IF (KLIC.EQ.0) STOP 777                                           REL.9.0
      IF (KLIC.GT.8) GO TO 99                                           REL.9.0
C
    5 DO 7 J=1,10
    7 IZT(J)=0
      IF (JMENO(1).NE.ICH) GO TO 4
      BACKSPACE 5
      READ (5,1005) IZT
      IZT(10)=1
c     pokus: bylo go to 4
      GO TO 8
C
C
    6 BACKSPACE 5
      JHD=0
C                                                                       REL 7.0
C     Test na cteni HD cisla hvezdy                                     REL 7.0
C                                                                       REL 7.0
      IF (JMENO(1).NE.IHD) GO TO 3
      READ (5,1004) JMENO(1),JHD,P
      CALL TAB (NOTAB,JHD,JMENO,V,*99)
      GO TO 4
C                                                                       REL 7.0
C     Test na pozadavek vypisu vsech hvezd najednou                     REL 7.0
C                                                                       REL 7.0
    3 READ (5,1003) (JMENO(J),J=1,3),P
      IF (JMENO(1).EQ.IALL) GO TO 4
C                                                                       REL 7.0
C     Identifikace HD pro jmeno hvezdy a precteni udaju z tabulky objektu   7.0
C                                                                       REL 7.0
      CALL TAB1 (NOTAB,JHD,JMENO,V,*99)
    4 BACKSPACE 5
      KB=0                                                              REL.9.2
      READ (5,9003) KOBS,KQ,KAP                                         REL.9.2
 9003 FORMAT(15X,I3,2I1)                                                REL.9.2
      KCS=0
      IF (KAP.GE.2) KCS=1
      KAP=MOD(KAP,2)
C
C
C
    8 IF (IN.NE.0) READ(5,9001) INP
      IF (IN.EQ.0.AND.IN0.EQ.0) THEN
      PRINT *,' No input archive file defined !!'
      GO TO 99
      END IF
      IN=11
      inquire(FILE=INP,EXIST=exist)
      if (exist) GO TO 12
      GO TO 12
      print *,' Required input archive file ',INP,' does not exist!'
      goto 99
   12 OPEN(UNIT=11,FILE=INP,FORM='FORMATTED',STATUS='OLD')              REL 7.0
      IN=11
      IN0=IN
C
C
      IF(OUT.NE.0) READ(5,9001) OUTP
      OUT=12
      inquire (FILE=OUTP,EXIST=exist)
C      IF (KLIC.LT.3.OR.KLIC.EQ.8) THEN                                 REL 7.0
C        OPEN(UNIT=OUT,FILE=OUTP,FORM='UNFORMATTED')                    REL 7.0
C        ELSE                                                           REL 7.0
      OPEN(UNIT=OUT,FILE=OUTP,FORM='FORMATTED')
      WRITE(OUT,2000)                                                   REL 8.1
 2000 FORMAT(/' VYPAR rel. 9.2     April 26, 2016')                     REL 9.2
      if (.NOT.exist) GO TO 13
    9   read (OUT,'(a)',END=10) line
      goto 9
   10   backspace OUT
   13 IF (KLIC.LT.3.OR.KLIC.GT.6) REWIND OUT                            REL 7.0
C
C
   11 IF(IZT(10).EQ.0) GO TO 2011
      READ(5,9001) INP1
      GO TO 1001
 2011 IF(IN2.LE.0.OR.IN2.GT.99.OR.KLIC.GT.1) GO TO 1001
      IN2=13
      READ(5,9001) INP1
      OPEN(UNIT=IN2,FILE=INP1,FORM='FORMATTED',STATUS='OLD')            REL 7.0
C
 1001 IF (DO.EQ.0.D0) DO=99999.9
      JMENO1=JMENO(1)
C
C
C
    2 IF (KLIC.LT.8.AND.INP.NE.INP0) CALL TEST (IN,KONEC,*1)
      INP0=INP
C
      GO TO (801,200,300,400,400,400,802,803),KLIC
C
C
  200 INP0='            '
      CALL COPY(*111)
      GO TO 111
C
  300 CALL CONT(*111,IZT,INTAB)
      GO TO 111
C
  400 CALL LIST(*111,P,JHD,V,PER,T0)
      GO TO 111
C
C
C 111 CLOSE (UNIT=OUT,STATUS='KEEP')
  111 CLOSE (UNIT=IN,STATUS='KEEP')                                     REL.9.0
      IN0=IN
      GO TO 1
C
   99 WRITE(*,89) KLIC                                                  REL.9.0
   89 FORMAT(' Non-existing regime',I2,' asked for, terminating!')      REL.9.0
      STOP
C                                                                       REL.9.0
C     The end for the regimes no longer used                            REL.9.0
C                                                                       REL.9.0
  801 WRITE(*,81) KLIC                                                  REL.9.0
   81 FORMAT(' Regime',I2,' (sorting the archives) is no'               REL.9.0
     *        ' longer provided.'/' Use the program SORTARCH')          REL.9.0
      STOP 001                                                          REL.9.0
C                                                                       REL.9.0
  802 WRITE(*,82) KLIC                                                  REL.9.0
   82 FORMAT(' Regime',I2,' (bin to ASCII transfer) is no longer'       REL.9.0
     *' available.'/' All archives are now stored in ASCII files')      REL.9.0
      STOP 007                                                          REL.9.0
C                                                                       REL.9.0
  803 WRITE(*,83) KLIC                                                  REL.9.0
   83 FORMAT(' Regime'I2,' (ASCII to bin transfer) is no longer'        REL.9.0
     *' available.'/' All archives are now stored in ASCII files')      REL.9.0
      STOP 008                                                          REL.9.0
      END
C
C  ************************************************
C
C  PODPROGRAM PRO TEST, JE-LI ARCHIV USPORADANY
C
C  ************************************************
C
      SUBROUTINE TEST (IN,KONEC,*)
C
      INTEGER*4 HD,DDT(10)
      CHARACTER*4 NAZEV,JM/'****'/
      COMMON /C1/NAZEV(6),ID,NHV,NM,HJDMIN,HJDMAX,HD(2000),D1(2000),
     *           D2(2000),NM1(2000),NM2(2000)
      COMMON /SYST/MSYS                                                 REL.8.1
C
C
      CHARACTER*12 INP,INP1,OUTP,INR
      COMMON /CT/INP,INP1,OUTP,NCOL
C
   10 FORMAT (10A4)
C
      NDAT=NCOL+6
      NDAT2=NCOL+2
      INR=INP
      IF (IN.EQ.13) INR=INP1
      KONEC=0
      NHV=0
    1 READ (IN,7001,END=7) ID                                           REL 7.0
C    ,(DDT(K),K=1,NDAT)                                                 REL 7.0
 7001 FORMAT(I5,I7,I10,2F12.4,6A4)                                      REL 7.0
      IF (ID.LT.0) GO TO 2
      KONEC=KONEC+1
      GO TO 1
C
    2 BACKSPACE IN
      READ (IN,7001) ID,NHV,NM,HJDMIN,HJDMAX,(NAZEV(K),K=1,NDAT2)       REL 7.0
 7002 FORMAT(I7,I7,I10,2F12.4,6A4)                                      REL 7.0
      IF (KONEC.NE.NM) GO TO 6
      DO 3 K=1,NHV
    3 READ (IN,7003) HD(K),D1(K),D2(K),NM1(K),NM2(K),                   REL 7.0
     *               (NAZEV(KK),KK=1,NDAT2)                             REL 7.0
 7003 FORMAT(I7,2F12.4,2I8,6A4)                                         REL 7.0
      KONEC=0
    4 READ (IN,7001,END=13) K
C    ,(DDT(KK),KK=1,NDAT)                       REL 7.0
      KONEC=KONEC+1
      GO TO 4
   13 IF (KONEC.EQ.0) GO TO 5
      WRITE(*,20) INR,KONEC
   20 FORMAT(/' Sorted part of archive  ',A12,
     *       ' is followed by ',I7,' not sorted data'//)
      GO TO 5
C
C
    6 NHV=0
      WRITE (*,11) INR,KONEC,NM
   11 FORMAT (/5X,'Error in archive ',A12,' - disagreement in number    REL 7.0
     * of data :',2I10//)                                               REL 7.0
      REWIND IN
      RETURN 1
    7 DO 8 J=1,5
    8 NAZEV(J)=JM
    5 REWIND IN
      RETURN
      END
C
C
C  **************************************************************
C
C  PODPROGRAM PRO CTENI UDAJU O DANE HVEZDE Z TABULKY NA FT77F001
C
C  **************************************************************
C
      SUBROUTINE TAB2 (ININ)
      CHARACTER*4 JM(3),JM1(3),JM2(3)
      CHARACTER*12 INP,INP1,OUTP                                        REL.8.1
      COMMON /SYST/MSYS                                                 REL.8.1
      COMMON /CT/INP,INP1,OUTP,NCOL                                     REL.8.1
      DIMENSION V(7)
      INTEGER*4 K,K1
      COMMON /TABST/IN
      DATA JM1/'    ','    ','    ' /
      IN=ININ
      REWIND IN
      RETURN
C  --------------------------------------------------------------
C
      ENTRY      TAB (NOTAB,K,JM,V,*)
C
C  --------------------------------------------------------------
C
C
   10 FORMAT (29X,4F7.3,I10,3A4)
   11 FORMAT (30X,4F7.3,I10,3A4)
C
    1 IF(NOTAB.EQ.0)
     * READ (IN,10,END=2) V(1),V(5),V(6),V(7),K1,(JM(J),J=1,3)          REL.9
      IF(NOTAB.NE.0)
     * READ (IN,11,END=2) V(1),V(5),V(6),V(7),K1,(JM(J),J=1,3)          REL.9
      IF (K.NE.K1) GO TO 1
      V(2)=V(1)+V(5)
      V(3)=V(2)+V(6)
      IF(MSYS.EQ.1.AND.NCOL.LE.3) V(3)=V(1)-V(6)                        REL.8.1
      V(4)=V(MSYS)-V(7)                                                 REL.8
      REWIND IN
      RETURN
C
    2 DO 3 J=1,6
    3 V(J)=0.
      DO 4 J=1,3
    4 JM(J)=JM1(J)
      WRITE (*,21) K
   21 FORMAT (//5X,'Star HD',I7 ,' not found in the table'//)
      GO TO 5
C
C
C  --------------------------------------------------------------
C
C
      ENTRY TAB1 (NOTAB,K,JM,V,*)
C
C  --------------------------------------------------------------
C
C  KE JMENU JM SE HLEDA HD CISLO
C
   12 IF(NOTAB.EQ.0) READ (IN,10,END=15) V(1),V(5),V(6),V(4),K,JM2
      IF(NOTAB.NE.0) READ (IN,11,END=15) V(1),V(5),V(6),V(4),K,JM2
      DO 13 J=1,3
      IF (JM(J).NE.JM2(J)) GO TO 12
   13 CONTINUE
      V(2)=V(1)+V(5)
      V(3)=V(2)+V(6)
      IF(MSYS.EQ.1.AND.NCOL.EQ.3) V(3)=V(1)-V(6)                        REL.8.1
      V(4)=V(MSYS)-V(4)                                                 REL.8
      REWIND IN
      RETURN
C
   15 K=0
      WRITE (*,20) JM
   20 FORMAT (//5X,'Star ',3A4, ' not found in the table')
    5 REWIND IN
      RETURN 1
      END
C
C  ***************************************************************
C
      SUBROUTINE K9K (K,HJD,*,*)
C
C  ***************************************************************
C
      REAL*8 OD,DO,HJD                                                  REL 7.0
      INTEGER*4 OUT                                                     REL 7.0
      CHARACTER*12 INP,INP1,OUTP                                        REL.8.1
      COMMON /CC/OD,DO,KLIC,IN,OUT,IN2,JMENO(5),                        REL 7.0
     *        KB,KAP,KCS,KQ,KOBS,KONEC,IQ,IAP,ICS,IEX,IOBS,NOTAB
      COMMON /SYST/MSYS                                                 REL.8.1
      COMMON /CT/INP,INP1,OUTP,NCOL                                     REL.8.1
      IF (HJD.LT.OD) RETURN1
      IF (HJD.GT.DO) RETURN2
      IQ=MOD(K,10)
      IAP=MOD(K/10,10)
      ICS=MOD(K/100,10)
      IEX=MOD(K/1000,10)
      IOBS=K/10000
      IF (IN2.EQ.0) GO TO 1
      IF (IQ.LT.KQ) GO TO 411
      IF (IAP.LT.KAP) GO TO 411
      IF (KOBS.NE.0.AND.KOBS.NE.IOBS) GO TO 411
      IF (ICS.LT.KCS) GO TO 411
    1 RETURN
  411 RETURN 1
      END
C
C
C
C  ***************************************************************
C
C
C
C  KOPIE ARCHIVU Z IN NA OUT
C         MUZE BYT USPORADANY I NEUSPORADANY
C         KOPIROVAT LZE NA TISKARNU I JINE MEDIUM
C
C  ***************************************************************
C
C
      SUBROUTINE COPY (*)
C
C  --------------------------------------------------------------
C
      INTEGER*4 DAT(9),NM3(2000),HD2(2000),IZT(10),DATA(12)
      CHARACTER*4 NAZEV,JMENO,NAME(3),TYP(2)/'abs.','dif.'/
      REAL*4 D3(2000),D4(2000),DATA1(11),F(2000,15),V(7),WP(4)          REL.9.0
      REAL*4 W(4)/.25,.5,1.,1.5/,LIMIT/99.999/
      REAL*8 VP(7),VM(7),RMS(4),TP,HJD
      REAL*8 OD,DO
      INTEGER*4 OUT,HD                                                  REL 9.0
      COMMON /CC/OD,DO,KLIC,IN,OUT,IN2,JMENO(5),                        REL 7.0
     *        KB,KAP,KCS,KQ,KOBS,KONEC,IQ,IAP,ICS,IEX,IOBS,NOTAB
      COMMON /SYST/MSYS                                                 REL.8.1
      COMMON /C1/NAZEV(6),ID,NHV,NM,HJDMIN,HJDMAX,HD(2000),D1(2000),
     *           D2(2000),NM1(2000),NM2(2000)
      EQUIVALENCE (DATA1(1),DAT(1),DATA(1))
C
      CHARACTER*12 INP,INP1,OUTP
      COMMON /CT/INP,INP1,OUTP,NCOL
      CHARACTER*24 COOR
C
C  --------------------------------------------------------------
C
 1002 FORMAT (10A4)
 1200 FORMAT (' Copying archive ',A12,' to ',A12)
 1201 FORMAT (5X,'Created archive ',A12,' contains',I7,2X,A4,
     *  ' data (sorted)'/15X,' for',I5,' stars'//)
 1202 FORMAT(5X,'Archive contains',I7,' not sorted data'///)
 1203 FORMAT (I11,F15.4,I8,7F9.3,I9)
 1204 FORMAT (///)
 1205 FORMAT (5X,'moreover')
 1206 FORMAT (10X,'selected only data for JD',F9.1,' -',F9.1)
 1207 FORMAT (10X,'selected only data from station N.',I4)
 1208 FORMAT (10X,
     *   'copied are only data from nights for absolute photometry')
 1209 FORMAT (10X,
     *   'copied are only data of quality >=',I3)
 1210 FORMAT (10X,
     *   'copied are only data from nights defining colour system')
 1211 FORMAT (1H+,2F9.3,I9)
C
      WRITE (*,1200) INP,OUTP
      IF(OD.GT.0D0.OR.DO.LT.99999D0) WRITE(*,1206) OD,DO
      IF (KOBS.NE.0) WRITE (*,1207) KOBS
      IF (KAP .NE.0) WRITE (*,1208)
      IF (KCS.NE.0) WRITE (*,1210)
      IF (KQ  .NE.0) WRITE (*,1209) KQ
      WRITE (*,1204)
C
C
C
      NDAT=NCOL+5
      NDAT1=NCOL+7
      NDAT2=NCOL+2
      NVM=5
      IF (NCOL.EQ.4) NVM=7
      NHV2=0
      DO 230 J=1,5
  230 NAZEV(J)=JMENO(J)
      IF (NHV)220,220,350
C
C
  210 IF (NHV2.GT.0) GO TO 211
      WRITE (*,1302) OD,DO
      IF (KONEC) 1,1,216
C
C
  211 WRITE (*,1201) OUTP,NM4,TYP(IABS(ID)),NHV2
      REWIND IN
      JEND=NCOL+2
      DO 212 J=1,NM
C      READ (IN,*) JHD,HJD,(DAT(K),K=1,NDAT)                            REL 7.0
      IF(NCOL.EQ.3) READ (IN,7001) JHD,HJD,DAT(1),DAT(2),               REL 7.0
     *  (DATA1(KM+2),KM=1,JEND),DAT(NDAT)                               REL 7.0
      IF(NCOL.EQ.4) READ (IN,7101) JHD,HJD,DAT(1),DAT(2),               REL 7.0
     *  (DATA1(KM+2),KM=1,JEND),DAT(NDAT)                               REL 7.0
      CALL K9K (DAT(2),HJD,*212,*212)
C      HJD=1.D-4*JD                                                     REL 7.0
C
C  209 WRITE (OUT) JHD,HJD,(DAT(K),K=1,NDAT)
  209 IF(NCOL.EQ.3) WRITE(OUT,7001) JHD,HJD,DAT(1),DAT(2),              REL 7.0
     *  (DATA1(KM+2),KM=1,JEND),DAT(NDAT)                               REL 7.0
      IF(NCOL.EQ.4) WRITE(OUT,7101) JHD,HJD,DAT(1),DAT(2),              REL 7.0
     *  (DATA1(KM+2),KM=1,JEND),DAT(NDAT)                               REL 7.0
  212 CONTINUE
C
      IF (OUT.EQ.0) GO TO 208
C
C
      WRITE (OUT,7004) ID,NHV2,NM4,DMIN,DMAX,(NAZEV(K),K=1,NDAT2)       REL 7.0
 7004 FORMAT(I5,I7,I10,2F12.4,10A4)                                     REL 7.0
      NM4=1
      DO 213 J=1,NHV2
      JMENO(4)='    '
      JMENO(5)='    '
      CALL TAB(NOTAB,HD2(J),JMENO,V,*2213)
 2213 WRITE (OUT,7003) HD2(J),D3(J),D4(J),NM4,NM3(J),                   REL 7.0
     *      (JMENO(K),K=1,4),(JMENO(K+1),K=3,NCOL)
 7003 FORMAT(I7,2F12.4,2I8,6A4)                                         REL 7.0
  213 NM4=NM4+NM3(J)
C
  208 IF (KONEC) 225,225,216
C
C
  216 N=NHV +1
      DO 217 J=1,N
  217 READ (IN)
      IF (OUT.EQ.6) WRITE (6,1204)
  220 NM4=0
      DO 221 J=1,KONEC
      READ (IN,*) JHD,HJD,(DAT(K),K=1,NDAT)                             REL 7.0
      CALL K9K (DAT(2),HJD,*221,*221)                                   REL 7.0
C      HJD=1.D-4*JD                                                     REL 7.0
  218 WRITE (OUT,*) JHD,JD,(DAT(K),K=1,NDAT)
  219 NM4=NM4+1
  221 CONTINUE
C
C
      IF (NHV.EQ.0) GO TO 227
      IF (NM4.EQ.0) GO TO 225
      WRITE (*,1205)
  227 WRITE (*,1202) NM4
      IF (OUT.EQ.0) GO TO 226
C
C
  225 IF (NM4+NHV2.GT.0.AND.OUT.NE.6) REWIND OUT
  226 REWIND IN
    1 RETURN 1
C
C  --------------------------------------------------------------
C
C
C  VYPIS OBSAHU ARCHIVU - POUZE PRO SETRIDENY ARCHIV
C
C  --------------------------------------------------------------
C
C
      ENTRY CONT (*,IZT,INTAB)
 1301 FORMAT (/5X,'Viewing content of archive ',A12,'....')
      WRITE (*,1301) INP
      IF (OD.GT.0D0.OR.DO.LT.99999D0) WRITE (*,1206) OD,DO
      IF (KOBS.NE.0) WRITE (*,1207) KOBS
      IF (KAP .NE.0) WRITE (*,1208)
      IF (KCS.NE.0) WRITE (*,1210)
      IF (KQ  .NE.0) WRITE (*,1209) KQ
 9301 FORMAT (/5X,'Content of the archive ',A12)
      WRITE(OUT,9301) INP
      IF (OD.GT.0D0.OR.DO.LT.99999D0) WRITE (OUT,1206) OD,DO
      IF (KOBS.NE.0) WRITE (OUT,1207) KOBS
      IF (KAP .NE.0) WRITE (OUT,1208)
      IF (KCS.NE.0) WRITE (OUT,1210)
      IF (KQ.NE.0) WRITE (OUT,1209) KQ
C
C
      NDAT=NCOL+5
      NDAT1=NCOL+7
      NDAT2=NCOL+2
      NVM=6
C
C
      IF (NHV.GT.0) GO TO 350
 1304 FORMAT (/5X,'Error - archive contains only',I7,
     *        ' not sorted data'//)
      WRITE (*,1304) KONEC
      GO TO 1
C
C
C
  350 NHV2=0
      NM4=0
      DMIN=DO
      DMAX=OD
      DO 301 J=1,NHV
      NM3(J)=0
      N=NM2(J)
      DO 310 I=1,NCOL
      VP(I)=0.
      WP(I)=0.0
  310 RMS(I)=0.
      TP=0.
      KHD=0
C
C
      JEND=NCOL+2
      DO 302 K=1,N
      IF(NCOL.EQ.3) READ (IN,7001) JHD,HJD,DAT(1),DAT(2),               REL 7.0
     *  (DATA1(KM+2),KM=1,JEND),DAT(NDAT)                               REL 7.0
      IF(NCOL.EQ.4) READ (IN,7101) JHD,HJD,DAT(1),DAT(2),               REL 7.0
     *  (DATA1(KM+2),KM=1,JEND),DAT(NDAT)                               REL 7.0
 7001 FORMAT(I7,F11.4,I10,I8,3F7.3,F6.3,F7.3,I7)                        REL 7.0
 7101 FORMAT(I7,F11.4,I10,I8,4F7.3,F6.3,F7.3,I7)                        REL 7.0
      CALL K9K (DAT(2),HJD,*302,*302)
      IF (NM3(J).EQ.0) D3(J)=HJD
      D4(J)=HJD
      NM3(J)=NM3(J)+1
      IF (KLIC.EQ.2) GO TO 302
      VM(1)=DATA1(3)
      VM(2)=DATA1(4)
      VM(3)=DATA1(5)
      IF (NCOL.EQ.4) VM(4)=DATA1(6)
      VM(5)=VM(2)-VM(1)
      VM(6)=VM(3)-VM(2)
      IF(MSYS.EQ.1.AND.NCOL.EQ.3) VM(6)=VM(1)-VM(3)                     REL.8.1
      VM(7)=VM(MSYS)-VM(4)                                              REL.8
      IF (ID.EQ.-1)  GO TO 311
      IF (DATA(NDAT).NE.KHD) CALL TAB (NOTAB,DATA(NDAT),JMENO,V,*32)
      KHD=DATA(NDAT)
      DO 312 I=1,NCOL
  312 VM(I)=VM(I)+V(I)
  311 W1=W(IQ+1)
C
C
      DO 313 I=1,NCOL
      IF (ABS(VM(I)).GT.LIMIT) GO TO 313
      WP(I)=WP(I)+W1
      VP(I)=VP(I)+W1*VM(I)
      RMS(I)=RMS(I)+W1*VM(I)**2
  313 CONTINUE
      TP=TP+W1*HJD
      GO TO 302
   32 WRITE(*,9300) JHD,JD
 9300 FORMAT (5X,'Error - comparison star HD',I7,
     *        ' not found in input table of objects !!'//)
  302 CONTINUE
C
C
C
      IF (NM3(J).EQ.0) GO TO 301
      NM4=NM4+NM3(J)
      NHV2=NHV2+1
      NM3(NHV2)=NM3(J)
      HD2(NHV2)=HD(J)
      D3(NHV2)=D3(J)
      D4(NHV2)=D4(J)
      IF (D3(J).LT.DMIN) DMIN=D3(J)
      IF (D4(J).GT.DMAX) DMAX=D4(J)
      IF (KLIC.EQ.2) GO TO 301
      K1=NM3(J)
C
C
      DO 315 I=1,NCOL
      IF (WP(I).EQ.0.0) THEN
      VP(I)=1.E5
      ELSE
      VP(I)=VP(I)/WP(I)
      END IF
      IF(K1.EQ.1) RMS(I)=0.
      IF(K1.LE.1.OR.WP(I).EQ.0.0) GO TO 4315                            REL.9
      Q=(RMS(I)-WP(I)*VP(I)**2)/(K1-1.)                                 REL.9
      IF(Q.GT.0.0) RMS(I)=SQRT(Q)                                       REL.9
      IF(Q.LE.0.0) RMS(I)=0.0                                           REL.9
 4315 F(NHV2,I)=VP(I)
      F(NHV2,I+11)=WP(I)                                                REL.9
  315 F(NHV2,I+7)=RMS(I)                                                REL.9
      IF (VP(3).GT.LIMIT) VP(3)=5.E5
      IF (NCOL.EQ.4.AND.VP(4).GT.LIMIT) VP(4)=1.E4
      F(NHV2,5)=VP(2)-VP(1)
      F(NHV2,6)=VP(3)-VP(2)
      IF(NCOL.EQ.4.AND.MSYS.EQ.1) F(NHV2,7)=VP(1)-VP(4)                 REL.9
      IF(NCOL.EQ.4.AND.MSYS.EQ.3) F(NHV2,7)=VP(3)-VP(4)                 REL.9
      DO 3315 I=1,6
 3315 IF (ABS(F(NHV2,I)).GT.LIMIT) F(NHV2,I)=LIMIT
  301 CONTINUE
C
C
C
      IF (KLIC.EQ.2) GO TO 210
C
C
      IF (NHV2.EQ.0) GO TO 304
 1305 FORMAT (/5X, 'Archive contains',I6,2X,A4,' data for JD',
     *    F 9.1,' -',F 9.1//5X,'for following',I5,' stars',
     *7X,'REM.:  rms - error of one meas.'//
     * 11X,' star   JD min  JD max   N.',4X,'V  rms(V)   w(V)',
     * 4X,'B  rms(B)   w(B)',4X,'U  rms(U)   w(U)',4X,'B-V    U-B'//)
 1306 FORMAT (I4,1X,3A4,2F8.1,I5,3(1X,F6.3,F6.3,F7.2),2(1X,F6.3))
C
 7305 FORMAT (/5X, 'Archive contains',I6,2X,A4,' data for JD',          REL 8.1
     *    F 9.1,' -',F 9.1//5X,'for following',I5,' stars',             REL 8.1
     *7X,'REM.:  rms - error of one meas.'//                            REL 8.1
     * 11X,' star   JD min  JD max   N.',4X,'V  rms(V)   w(V)',         REL 8.1
     * 4X,'B  rms(B)   w(B)',4X,'U  rms(U)   w(U)',4X,'R  rms(R)   w(R)'REL 8.1
     * 3X,'B-V    U-B    V-R'//)                                        REL 8.1
C
 9305 FORMAT (/5X, 'Archive contains',I6,2X,A4,' data for JD',
     *    F 9.1,' -',F 9.1//5X,'for following',I5,' stars',
     *7X,'REM.  rms - error of one meas.'//
     * 11X,' star   JD min  JD max   N.',4X,'y  rms(y)   w(y)',
     * 4X,'b  rms(b)   w(b)',4X,'u  rms(u)   w(u)',
     * 4X,'v  rms(v)   w(v)',3X,'b-y    u-b    u-v'//)                  REL 8.1
 9306 FORMAT (I4,1X,3A4,2F8.1,I5,4(1X,F6.3,F6.3,F7.2),3(1X,F6.3))       REL 8.1
C
C
      IF (NCOL.EQ.3)                                                    REL 8.1
     *  WRITE (OUT,1305) NM4,TYP(IABS(ID)),DMIN,DMAX,NHV2               REL 8.1
      IF(NCOL.EQ.4.AND.MSYS.EQ.3)                                       REL 8.1
     *  WRITE (OUT,9305) NM4,TYP(IABS(ID)),DMIN,DMAX,NHV2               REL 8.1
      IF(NCOL.EQ.4.AND.MSYS.EQ.1)                                       REL 8.1
     *  WRITE (OUT,7305) NM4,TYP(IABS(ID)),DMIN,DMAX,NHV2               REL 8.1
      DO 303 J=1,NHV2
      CALL TAB (NOTAB,HD2(J),NAME,V,*303)
      IF(NCOL.EQ.3) WRITE (OUT,1306)J,NAME,D3(J),D4(J),NM3(J),          REL 8.1
     *        (F(J,I),F(J,I+7),F(J,I+11),I=1,NCOL),F(J,5),F(J,6)        REL.9.2
      IF(NCOL.EQ.4)                                                     REL 8.1
     *    WRITE (OUT,9306)J,NAME,D3(J),D4(J),NM3(J),                    REL 8.1
     *   (F(J,I),F(J,I+7),F(J,I+11),I=1,NCOL),F(J,5),F(J,6),F(J,7)      REL 8.1
  303 CONTINUE
C
C
C
      IF (IZT(10).EQ.0) GO TO 305
      INTAB1=INTAB+1
      OPEN(UNIT=INTAB1,FILE=INP1,STATUS='NEW')
 1310 FORMAT(I3,I2,A24,4F7.3,I10,3A4,I1)
 2310 FORMAT(I4,I2,A24,4F7.3,I10,3A4)
  351 IF(NOTAB.EQ.0)
     *READ (INTAB,1310,END=352)I,IT,COOR,V(1),V(5),V(6),V(4),JHD,NAME,K
      IF(NOTAB.GT.0)
     *READ (INTAB,2310,END=352)I,IT,COOR,V(1),V(5),V(6),V(4),JHD,NAME
      IF (IZT(IT).EQ.0) GO TO 355
      J=0
  353 J=J+1
      IF (HD2(J)-JHD) 353,354,355
  354 IF(NOTAB.EQ.0) WRITE (INTAB1,1310)
     *       I,IT,COOR,F(J,1),F(J,5),F(J,6),F(J,7),JHD,NAME
      IF(NOTAB.GT.0) WRITE (INTAB1,2310)
     *       I,IT,COOR,F(J,1),F(J,5),F(J,6),F(J,7),JHD,NAME

      GO TO 351
  355 IF(NOTAB.EQ.0)
     *WRITE (INTAB1,1310) I,IT,COOR,V(1),V(5),V(6),V(4),JHD,NAME
      IF(NOTAB.GT.0)
     *WRITE (INTAB1,2310) I,IT,COOR,V(1),V(5),V(6),V(4),JHD,NAME
      GO TO 351
 1311 FORMAT (///5X,'NEW MEAN ',A4,' VALUES INCLUDED IN THE STAR TABLE '
     * ,A12//)
  352 WRITE (*,1311) TYP(IABS(ID)),INP1
      REWIND INTAB
      INTAB=INTAB1
      ENDFILE INTAB
      REWIND INTAB
      CALL TAB2(INTAB)
      GO TO 305
  304 WRITE (OUT,1302) OD,DO
 1302 FORMAT (5X,'Archive contains no data for JD',F10.1,' -',
     *        F10.1/15X,'with properties required')
  305 IF (KONEC.EQ.0) GO TO 307
C
C
      N=NHV+1
      DO 306 J=1,N
  306 READ (IN)
      N=0
      DO 308 J=1,KONEC
      READ (IN,*) JHD,HJD,DAT                                           REL 7.0
      CALL K9K (DAT(2),HJD,*308,*308)                                   REL 7.0
C      HJD=1.D-4*JD                                                     REL 7.0
      N=N+1
  308 CONTINUE
      IF (N.GT.0) WRITE (OUT,1303) N
      IF (N.GT.0) WRITE (*,1303) N
C
 1303 FORMAT (//5X,'Sorted part of archive contains',I5,
     *       ' not sorted data'/)
C
C
  307 REWIND IN
      GO TO 1
      END
C
C
C
C  VYPIS JEDNOTLIVE HVEZDY    KLIC=4 NEBO 5 NEBO 6
C         KLIC = 4    INDIVIDUALNI BODY
C         KLIC = 5    PRUMERY S PEVNYM POCATKEM
C         KLIC = 6    PRUMERY S POHYBLIVYM POCATKEM
C
C
      SUBROUTINE LIST (*,P,JHD,V,PER,T0)
C
      REAL*8 P,PP,HJD,PHASE,PER,T0,TP,T2,VP(7),RMS(6),VM(7),RMSPH,WP
      CHARACTER*4 NAZEV,JMENO,NAME(3),BARVA(6,2)
      CHARACTER*4 JPOZOR(3),BLANK,TYP(2)/'abs.','dif.'/,KPOZOR(3)
      CHARACTER*4 MANY/4Hmany/
      INTEGER*4 HD2(300),DATA(12),DAT(9)
      REAL*4 W(4),V(7),DATA1(12),LIMIT/99.999/
      EQUIVALENCE (DATA1(1),DATA(1),DAT(1))
      REAL*8 OD,DO
      INTEGER*4 OUT,HD,J111(3)                                          REL 9.0
      COMMON /CC/OD,DO,KLIC,IN,OUT,IN2,JMENO(5),                        REL 7.0
     *        KB,KAP,KCS,KQ,KOBS,KONEC,IQ,IAP,ICS,IEX,IOBS,NOTAB
      COMMON /C1/NAZEV(6),ID,NHV,NM,HJDMIN,HJDMAX,HD(2000),D1(2000),
     *           D2(2000),NM1(2000),NM2(2000)
      COMMON /SYST/MSYS                                                 REL.8.1
C
      CHARACTER*12 INP,INP1,OUTP
      CHARACTER*4 OBSR
      COMMON /CO/NOR,OBSR(400)
      COMMON /CT/INP,INP1,OUTP,NCOL
C
 1002 FORMAT (10A4)
      DATA BARVA/' V  ',' B  ',' U  ','    ',' B-V',' U-B',
     *           ' y  ',' b  ',' u  ',' v  ',' b-y',' u-b'/
      DATA W /0.25,0.5,1.0,1.5/
      DATA BLANK/4H    /
C
 1400 FORMAT (/5X,'List of measurements for star ',3A4,' (HD',I7,
     *  ')'/10X,'from ',A4,' archive ',A12)
 9400 FORMAT (' Producing ....')
 9401 FORMAT (/15X,'REM.:  rms - error of one measurement')
 1401 FORMAT (10X,'Individual measurements')
 1402 FORMAT(/10X,'Ephemeris used : PER =',G15.8,'  T =',F12.4/)
 1403 FORMAT(10X,'Fixed means by',F9.3,' day(s)')
 1404 FORMAT(10X,'Floating means by',F9.3,' day(s)')
 1405 FORMAT(10X,'used only data from station N.',I4)
 1406 FORMAT(10X,'used only data from nights for absolute photometry')
 1407 FORMAT(10X,'used only data with quality >=',I3)
 1408 FORMAT(10X,'all colours'/)
 1409 FORMAT(10X,'colour ',A4/)
 1410 FORMAT (F12.4,F9.3,F6.2,6(1X,F6.3),I4,1X,3A4)
 8410 FORMAT (F12.4,F9.3,F6.2,8(1X,F6.3),I4,1X,3A4)                     REL.9
 9410 FORMAT (F12.4,F9.3,F6.2,7(1X,F6.3),I4,1X,3A4)
 1411 FORMAT (F12.4,F9.3,F6.2,6(1X,F6.3),F7.3,I7,I4,1X,3A4)             REL 7.0
 8411 FORMAT (F12.4,F9.3,F6.2,8(1X,F6.3),F7.3,I7,I4,1X,3A4)             REL 9.0
 9411 FORMAT (F12.4,F9.3,F6.2,7(1X,F6.3),F7.3,I7,I4,1X,3A4)             REL 7.0
 1412 FORMAT (//8X,' HJD',4X,'phase   w      V',6X,'B',6X,'U',
     *        4X,' B-V    U-B',5X,'X  ',' sta observers')
 7412 FORMAT (//8X,' HJD',4X,'phase   w      V',6X,'B',6X,'R',          REL.8.1
     *        4X,' B-V    V-R',5X,'X  ',' sta observers')               REL.8.1
 8412 FORMAT (//8X,' HJD',4X,'phase   w      V',6X,'B',6X,'U',6X,'R',   REL.8
     *        5X,'B-V    U-B    V-R',5X,'X  ',' sta observers')         REL.9
 9412 FORMAT (//8X,' HJD',4X,'phase   w      y',6X,'b',6X,'u',6X,'v',
     *        5X,'b-y    u-b    u-v',5X,'X  ',' sta observers')         REL.9.1
 1413 FORMAT (//8X,' HJD',4X,'phase   w      V',6X,'B',6X,'U',
     *     4X,' B-V    U-B',5X,'X  ','   dX   HDcomp',' sta observers')
 7413 FORMAT (//8X,' HJD',4X,'phase   w      V',6X,'B',6X,'R',          REL.8.1
     *     4X,' B-V    V-R',5X,'X  ','   dX   HDcomp',' sta observers') REL.8.1
 8413 FORMAT (//8X,' HJD',4X,'phase   w      V',6X,'B',6X,'U',6X,'R',   REL.8
     *     5X,'B-V    U-B',4X,'V-R',5X,'X  ',                           REL.9
     *     '   dX   HDcomp',' sta observers')                           REL.9
 9413 FORMAT (//8X,' HJD',4X,'phase   w      y',6X,'b',6X,'u',6X,'v',
     *     5X,'b-y    u-b    u-v',5X,'X  ',                             REL9.1
     *     '   dX   HDcomp',' sta observers')                           REL9.1
C 1413 FORMAT (1H+,'  dX  HD comp')
 1414 FORMAT (/'   standard values',9X,7F7.3)                           REL.9
 1417 FORMAT(/5X,'Archive contains no data with required properties'/)
C 1418 FORMAT (1H+,I3,1X,3A4)
 1419 FORMAT (1H+,'obs observers')
 1420 FORMAT (/5X,'Number of points :',I5)
 1421 FORMAT (/5X,'Comparison stars used :'//9X,'HD',9X,' star',4X,
     *        'V',6X,'B-V',4X,'U-B'/)
 8421 FORMAT (/5X,'Comparison stars used :'//9X,'HD',9X,' star',5X,     REL.8
     *        'V',5X,'B-V',4X,'U-B',4X,'V-R'/)                          REL.8
 9421 FORMAT (/5X,'Comparison stars used :'//9X,'HD',9X,' star',5X,
     *        'y',5X,'b-y',4X,'u-b',4X,'u-v'/)                          REL.8
 1422 FORMAT (I12,2X,3A4,4F7.3)
 1423 FORMAT (10X,' for JD',F9.1,' -',F9.1)
C 1424 FORMAT (5X,'Floating means by',F9.3,' day(s) for JD',F9.1,' -',F9.1)
 1425 FORMAT(/)
 1426 FORMAT (T90,'NA FT',I2,'F001'/)
 1427 FORMAT(10X,'used only data from nights defining colour system')
C
C
      IF (NHV.EQ.0) GO TO 97
C
      IF (NOR.EQ.0) THEN
      OPEN(97,FILE='observer',STATUS='OLD')
 4403 FORMAT (80A1)
 4404 FORMAT (I3,A4,A70)
      READ(97,4403)
      READ(97,4403)
      READ(97,4403)
 4401   READ(97,4404,END=4402) NOR,OBSR(NOR)
      GO TO 4401
 4402   CLOSE(97,STATUS='KEEP')
      END IF
C
      NDAT=NCOL+5
      NDAT1=NCOL+7
      NDAT2=NCOL+2
      NPART=0
      NPART1=0
      NC1=MAX(1,KB)
      NC2=KB
      IF (KB.EQ.0) NC2=NCOL
      NJHD=JHD
      NHD=0
C
C      IF (OUT.EQ.6) KB=0
      PP=P
  450 IF (NJHD.GT.0) GO TO 451
      P=PP
      NHD=NHD+1
      JHD=HD(NHD)
  451 CALL TAB (NOTAB,JHD,JMENO,V,*496)
C 451 bylo tady
      WRITE (*,9400)
      WRITE (*,1400) (JMENO(J),J=1,3),JHD,TYP(IABS(ID)),INP
      WRITE (OUT,1400) (JMENO(J),J=1,3),JHD,TYP(IABS(ID)),INP
C
      IF (KLIC.EQ.4) WRITE (*,1401)
      IF (KLIC.EQ.5) WRITE (*,1403) P
      IF (KLIC.EQ.6) WRITE (*,1404) P
      IF (KLIC.EQ.4) WRITE (OUT,1401)
      IF (KLIC.EQ.5) WRITE (OUT,1403) P
      IF (KLIC.EQ.6) WRITE (OUT,1404) P
      IF (OD.GT.1D0.OR.DO.LT.99999.0D0) THEN
      WRITE(*,1423) OD,DO
      WRITE(OUT,1423) OD,DO
      END IF
C
      IF (KB.GT.0) THEN
      WRITE (*,1409) BARVA(KB,NCOL-2)
      ELSE
      WRITE (*,1408)
      END IF
      IF (KOBS.NE.0) WRITE (*,1405) KOBS
      IF (ID.EQ.-1.AND.KAP.GT.0) WRITE (*,1406)
      IF (KCS.NE.0) WRITE (*,1427)
      IF (KQ.GT.0) WRITE (*,1407) KQ
      IF (PER.GT.0D0) WRITE (*,1402) PER,T0
       IF (KB.GT.0) THEN
      WRITE (OUT,1409) BARVA(KB,NCOL-2)
      ELSE
      WRITE (OUT,1408)
      END IF
      IF (KOBS.NE.0) WRITE (OUT,1405) KOBS
      IF (ID.EQ.-1.AND.KAP.GT.0) WRITE (OUT,1406)
      IF (KCS.NE.0) WRITE (OUT,1427)
      IF (KQ.GT.0) WRITE (OUT,1407) KQ
      IF (PER.GT.0D0) WRITE (OUT,1402) PER,T0
      J=NHD
      IF (NJHD.EQ.0) GO TO 402
C
C
      DO 401 J=1,NHV
      IF (HD(J).EQ.JHD) GO TO 402
  401 CONTINUE
  404 WRITE (*,1417)
      WRITE (OUT,1417)
      GO TO 1
C
C
  402 IF (D1(J).GT.DO.OR.D2(J).LT.OD) GO TO 404
      N=NM1(J)-1
      NM4=NM2(J)
      IF (N.EQ.0) GO TO 406
      DO 403 J=1,N
  403 READ (IN,*)                                                       REL 7.0
  406 DO 405 J=1,300
  405 HD2(J)=0
      KHD=0
      NHDC=0
C
      IF (KLIC.NE.4) GO TO 501
C
C  INDIVIDUAL OBSERVATIONS
C
      IF (NCOL.EQ.3.AND.ID.EQ.-1.AND.MSYS.EQ.3) WRITE (OUT,1412)        REL.8.1
      IF (NCOL.EQ.3.AND.ID.NE.-1.AND.MSYS.EQ.3) WRITE (OUT,1413)        REL.8.1
      IF (NCOL.EQ.3.AND.ID.EQ.-1.AND.MSYS.EQ.1) WRITE (OUT,7412)        REL.8.1
      IF (NCOL.EQ.3.AND.ID.NE.-1.AND.MSYS.EQ.1) WRITE (OUT,7413)        REL.8.1
      IF (NCOL.EQ.4.AND.ID.EQ.-1.AND.MSYS.EQ.3) WRITE (OUT,9412)        REL.8
      IF (NCOL.EQ.4.AND.ID.NE.-1.AND.MSYS.EQ.3) WRITE (OUT,9413)        REL.8
      IF (NCOL.EQ.4.AND.ID.EQ.-1.AND.MSYS.EQ.1) WRITE (OUT,8412)        REL.8
      IF (NCOL.EQ.4.AND.ID.NE.-1.AND.MSYS.EQ.1) WRITE (OUT,8413)        REL 8
      WRITE (OUT,1414) (V(K),K=1,NCOL),V(5),V(6),V(7)                   REL 9
      WRITE (OUT,1425)
C
C
C  SPOLECNE CTENI JEDNOHO BODU PRO KLICE 4,5,6
C
C
  410 J1=0
      NR=0
  411 J1=J1+1
      IF (J1.GT.NM4) GO TO 499
      JEND=NCOL+2
      IF(NCOL.EQ.3) READ (IN,7001) K,HJD,DAT(1),DAT(2),                 REL 7.0
     *(DATA1(KM+2),KM=1,JEND),DAT(NDAT)                                 REL 7.0
      IF(NCOL.EQ.4) READ (IN,7002) K,HJD,DAT(1),DAT(2),                 REL 7.0
     *(DATA1(KM+2),KM=1,JEND),DAT(NDAT)                                 REL 7.0
 7001 FORMAT(I7,F11.4,I10,I8,3F7.3,F6.3,F7.3,I7)                        REL 7.0
 7002 FORMAT(I7,F11.4,I10,I8,4F7.3,F6.3,F7.3,I7)                        REL 7.0
C      READ (IN,*) K,JD,(DAT(KK),KK=1,NDAT)                             REL 7.0
      IF (K.NE.JHD) GO TO 497
      CALL K9K (DAT(2),HJD,*411,*499)                                   REL 7.0
      J111(1)=DAT(1)/1000000
      J=DAT(1)-1000000*J111(1)
      J111(2)=J/1000
      J111(3)=J-1000*J111(2)
      DO 507 J=1,3
      JPQR=J111(J)
      IF(JPQR.LE.0) GO TO 508
      JPOZOR(4-J)=OBSR(JPQR)
      GO TO 507
  508 JPOZOR(4-J)=BLANK
  507 CONTINUE
C      HJD=1.D-4*JD                                                     REL 7.0
      VM(1)=DATA1(3)
      VM(2)=DATA1(4)
      VM(3)=DATA1(5)
      IF (NCOL.EQ.4) VM(4)=DATA1(6)
      VM(5)=VM(2)-VM(1)
      VM(6)=VM(3)-VM(2)
      IF(MSYS.EQ.1.AND.NCOL.EQ.3) VM(6)=VM(1)-VM(3)                     REL.8.1
      IF(NCOL.EQ.4) VM(7)=VM(MSYS)-VM(4)                                REL.9.1
C
C  OPRAVA O SROVNAVACI *
C
      IF (ID.EQ.-1) GO TO 420
      IF (DATA(NDAT).NE.KHD) CALL TAB (NOTAB,DATA(NDAT),NAME,V,*416)
  416 KHD=DATA(NDAT)
      IF (NHDC.EQ.0) GO TO 413
      DO 412 J=1,NHDC
      IF (HD2(J).EQ.KHD) GO TO 414
  412 CONTINUE
  413 NHDC=NHDC+1
      HD2(NHDC)=KHD
  414 DO 415 J=1,7                                                      REL.9
  415 VM(J)=VM(J)+V(J)
  420 IF (KLIC.NE.4) GO TO 510
C
C
C   TISKY INDIVIDUALNICH MERENI
C
C
      NR=NR+1
  423 PHASE=0.
      DO 425 J=1,6
  425 IF (ABS(VM(J)).GT.LIMIT) VM(J)=LIMIT
      IF (PER.NE.0D0) PHASE=( HJD-T0)/PER
      IF (NCOL.EQ.3) THEN
        IF (ID.EQ.-1) THEN
          WRITE (OUT,1410) HJD,PHASE,W(IQ+1),(VM(K),K=1,NCOL),
     *       VM(5),VM(6),DATA1(NCOL+3),IOBS,JPOZOR
          ELSE
          WRITE (OUT,1411) HJD,PHASE,W(IQ+1),(VM(K),K=1,NCOL),
     *       VM(5),VM(6),DATA1(NCOL+3),DATA1(NCOL+4),KHD,IOBS,JPOZOR
          END IF
        ELSE
        IF (ID.EQ.-1) THEN
        IF(MSYS.NE.1) WRITE (OUT,9410) HJD,PHASE,W(IQ+1),               REL.9
     * (VM(K),K=1,NCOL),VM(5),VM(6),VM(7),DATA1(NCOL+3),IOBS,JPOZOR     REL.9
        IF(MSYS.EQ.1) WRITE (OUT,8410) HJD,PHASE,W(IQ+1),               REL.9
     * (VM(K),K=1,NCOL),VM(5),VM(6),VM(7),DATA1(NCOL+3),IOBS,JPOZOR     REL.9
          ELSE
        IF(MSYS.NE.1) WRITE (OUT,8411)HJD,PHASE,W(IQ+1),                REL.9
     * (VM(K),K=1,NCOL),VM(5),VM(6),VM(7),DATA1(NCOL+3),                REL.9
     * DATA1(NCOL+4),KHD,IOBS,JPOZOR                                    REL.9
        IF(MSYS.EQ.1) WRITE (OUT,8411)HJD,PHASE,W(IQ+1),                REL.9
     * (VM(K),K=1,NCOL),VM(5),VM(6),VM(7),DATA1(NCOL+3),                REL.9
     * DATA1(NCOL+4),KHD,IOBS,JPOZOR                                    REL.9
          END IF
        END IF
      GO TO 411
C
C
C  SPOLECNY KONEC PRO KLICE 4,5,6
C
C
  497 WRITE (OUT,1497) JHD,K
      WRITE (*,1497) JHD,K
      GO TO 411
 1497 FORMAT (/5X ,'Error in archive - disagreement of HD',2I10/)
  499 REWIND IN
      IF (KLIC.GT.4.AND.N.GT.0) GO TO 512
  498 IF (NR.GT.0) GO TO 492
      WRITE (OUT,1417)
      WRITE (*,1417)
      GO TO 491
  496 WRITE (OUT,1496) (JMENO(K),K=1,3)
      WRITE (*,1496) (JMENO(K),K=1,3)
 1496 FORMAT (/5X,'Error - star ',3A4,', not found in the table !!'/)
      GO TO 1
  492 IF (ID.EQ.-1) GO TO 491
      IF (NCOL.EQ.3) WRITE (OUT,1421)                                   REL.8
      IF (NCOL.EQ.4.AND.MSYS.EQ.1) WRITE(OUT,8421)                      REL.8
      IF (NCOL.EQ.4.AND.MSYS.EQ.3) WRITE(OUT,9421)                      REL.8
      DO 493 J=1,NHDC
      CALL TAB (NOTAB,HD2(J),NAME ,V,*493)
      V4=V(MSYS)-V(4)                                                   REL.8
      IF (NCOL.EQ.3) THEN
        WRITE (OUT,1422) HD2(J),NAME ,V(1),V(5),V(6)
        ELSE
        WRITE (OUT,1422) HD2(J),NAME ,V(1),V(5),V(6),V4                 REL.8
        END IF
  493 CONTINUE
  491 IF (KLIC.GT.4.AND.KB.EQ.0.AND.NPART.GT.0) THEN
        WRITE (OUT,1555) NPART
        WRITE (*,1555) NPART
 1555 FORMAT (//
     * ' !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'/
     * ' Archive contains',I5,' records with not all colours measured'/
     * 5X,'They were not included in the means'/
     * 5X,'To include all data individual colours must be listed!'/
     * ' !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'
     * //)
        NPART=0
        END IF
C
C
      IF (NJHD.NE.0) GO TO 1
      IF (NHD-NHV) 450,1,1
C
C  --------------------------------------------------------------
C
C  ODBOCKY PRO KLICE 5 A 6
C
C  --------------------------------------------------------------
C
C
 1500 FORMAT (/5X,'HJD ',6X,'phase   N weight    V',5X,'rms    B',5X,
     *  'rms    U',5X,'rms   B-V    U-B     X   ',
     *  ' sta  observers')                                              REL.9.2
 7500 FORMAT (/5X,'HJD ',6X,'phase   N weight    V',5X,'rms    B',5X,   REL.8.1
     *  'rms    U',5X,'rms   B-V    U-B     X   ',                      REL.8.1
     *  ' sta  observers')                                              REL.9.2
 8500 FORMAT (/5X,'HJD ',6X,'phase   N weight    V',5X,'rms    B',5X,   REL.8.1
     *  'rms    U',5X,'rms    R',5X,'rms    B-V    U-B   V-R   X   ',   REL.8.1
     *  ' sta  observers')                                              REL.9.2
 9500 FORMAT (/5X,'HJD ',6X,'phase   N weight    y',5X,'rms    b',5X,
     *  'rms    u',5X,'rms    v',5X,'rms    b-y    u-b   X   ',
     *  '  sta observers')                                              REL.9.2
 1501 FORMAT (/5X,'HJD ',6X,'phase   N weight    V',5X,'rms    B',5X,
     *  'rms    U',5X,'rms   B-V    U-B     X   ',
     *  '   dX  HDcomp',' sta  observers')                              REL.9.2
 7501 FORMAT (/5X,'HJD ',6X,'phase   N weight    V',5X,'rms    B',5X,   REL.8.1
     *  'rms    R',5X,'rms   B-V    V-R     X   ',                      REL.8.1
     *  '   dX  HDcomp',' sta  observers')                              REL.9.2
 8501 FORMAT (/5X,'HJD ',6X,'phase   N weight    V',4X,'rms     B',4X,  REL.8
     *  'rms     U',4X,'rms     R',4X,'rms    B-V    U-B    V-R',5X,'X',REL.9
     *  5X,'dX  HDcomp',' sta  observers')                              REL.9.2
 9501 FORMAT (/5X,'HJD ',6X,'phase   N weight    y',4X,'rms     b',4X,  REL.9.1
     *  'rms     u',4X,'rms     v',4X,                                  REL.9.1
     *  'rms    b-y    u-b    u-v     X   ',                            REL.9.1
     *  '   dX  HDcomp',' sta  observers')                              REL.9.2
 1502 FORMAT (/5X,'Standard values',11X,3(F7.3,6X),2F7.3/)
 8502 FORMAT (/5X,'Standard values',11X,4(F7.3,6X),3F7.3/)              REL 9.0
 9502 FORMAT (/5X,'Standard values',11X,4(F7.3,6X),2F7.3/)              REL 7.0
 1503 FORMAT(F11.4,F9.3,I4,F7.2,3(1X,2F6.3),2(1X,F6.3),F7.3,            REL 7.0
     *       2X,I3,1X,3A4)                                              REL.9.2
 9503 FORMAT(F11.4,F9.3,I4,F7.2,4(1X,2F6.3),2(1X,F6.3),F7.3,            REL 7.0
     *       2X,I3,1X,3A4)                                              REL.9.2
 1504 FORMAT(F11.4,F9.3,I4,F7.2,3(1X,2F6.3),2(1X,F6.3),2F7.3,I7,        REL 9.1
     *       2X,I3,1X,3A4)                                              REL.9.2
 7504 FORMAT(F11.4,F9.3,I4,F7.2,3(1X,2F6.3),2(1X,F6.3),2F7.3,I7,        REL 9.1
     *       2X,I3,1X,3A4)                                              REL 9.2
 8504 FORMAT(F11.4,F9.3,I4,F7.2,4(1X,2F6.3),3(1X,F6.3),2F7.3,I7,        REL 9.0
     *       2X,I3,1X,3A4)                                              REL 9.2
 9504 FORMAT(F11.4,F9.3,I4,F7.2,4(1X,2F6.3),3(1X,F6.3),F7.3,I7,         REL 7.0
     *       2X,I3,1X,3A4)                                              REL.9.2
 1507 FORMAT(F11.4,F10.3,I4,F7.2,F7.3,F6.3,F7.3,2X,I3,1X,3A4)           REL.9.2
 1508 FORMAT(F11.4,F10.3,I4,F7.2,F7.3,F6.3,F7.3,F6.3,I7,2X,I3,1X,3A4)
 1509 FORMAT (/7X,'   Standard value ',7X ,F7.3/)
 1550 FORMAT (/6X,'HJD ',6X,'phase   N weight  ',A4,4X,'rms   X   ',
     *        ' sta  observers')                                        REL.9.2
 1551 FORMAT (/6X,'HJD ',6X,'phase   N weight  ',A4,4X,'rms   X   ',
     *        '   dX  HDcomp',' sta  observers')                        REL.9.2
C
C
C
  501 IF (KB.GT.0) THEN
C
        IF (ID.EQ.-1) THEN
          WRITE (OUT,1550) BARVA(KB,NCOL-2)
          ELSE
          WRITE (OUT,1551) BARVA(KB,NCOL-2)
          END IF
        WRITE (OUT,1509) V(KB)
C
        ELSE
        IF (NCOL.EQ.3) THEN
          IF (ID.EQ.-1) THEN
            WRITE (OUT,1500)
            ELSE
            WRITE (OUT,1501)
            END IF
          WRITE (OUT,1502) V(1),V(2),V(3),V(5),V(6)
          ELSE
          IF (ID.EQ.-1) THEN
            WRITE (OUT,9500)
            ELSE
            IF(MSYS.NE.1) WRITE (OUT,9501)                              REL.8
            IF(MSYS.EQ.1) WRITE (OUT,8501)                              REL.8
            END IF
          IF(NCOL.LE.3) WRITE (OUT,9502) (V(K),K=1,6)                   REL.9.1
          IF(NCOL.EQ.4) WRITE (OUT,8502) (V(K),K=1,7)                   REL.9.1
          END IF
        END IF
C
C
      IF (KLIC.EQ.6.AND.P.GE.1.) P=P-.3
      T2=OD
      N=0
      GO TO 410
C
C  --------------------------------------------------------------
C
C  PRIDANI JEDNOHO MERENI
C
C  --------------------------------------------------------------
C
  510 IF(HJD.GT.T2) GO TO 512
  509 W1=W(IQ+1)
      NPART1=0
      DO 551 J=NC1,NC2
  551 IF (ABS(VM(J)).GT.LIMIT) NPART1=NPART1+1
      IF (NPART1.GT.0) THEN
        NPART=NPART+1
        GO TO 411
        ELSE
          DO 511 J=NC1,NC2
          VP(J)=VP(J)+W1*VM(J)
  511     RMS(J)=RMS(J)+W1*VM(J)**2
          TP=TP+W1*HJD
          WP=WP+W1
          N=N+1
          XP=XP+W1*DATA1(NCOL+3)
          DXP=DXP+W1*DATA1(NCOL+4)
          IF (IQ.NE.NQ) NQ=10
          IF (IAP.NE.NAP) NAP=10
          IF (IEX.NE.NEX) NEX=10
          IF (ICS.NE.NCS) NCS=10
          IF (IOBS.NE.NOBS) NOBS=2000
          IF (NHKD.NE.KHD) NHKD=1000000000
          IF (DAT(1).NE.NPOZOR) THEN
            NPOZOR=0
            KPOZOR(2)=BLANK
            KPOZOR(3)=BLANK
            KPOZOR(1)=MANY
            END IF
          GO TO 411
        END IF
C
C  VYPOCET PRUMERU A TISK BODU
C
  512 IF (N.EQ.0) GO TO 520
      NR=NR+1
      DO 513 J=NC1,NC2
      VP(J)=VP(J)/WP
      IF(N.LE.1) GO TO 5513
      RMSPH=(RMS(J)-WP*VP(J)**2)/(N-1.)
      IF(RMSPH.LE.0D0) GO TO 5513
      RMS(J)=DSQRT(RMSPH)
      GO TO 513
 5513 RMS(J)=0.
  513 CONTINUE
      IF (KB.NE.0) GO TO 7050
      VP(5)=VP(2)-VP(1)
      VP(6)=VP(3)-VP(2)
      IF(MSYS.EQ.1.AND.NCOL.EQ.3) VP(6)=VP(1)-VP(3)                     REL.8.1
      IF(NCOL.EQ.4) VP(7)=VP(MSYS)-VP(4)                                REL 9.1
 7050 XP=XP/WP
      TP=TP/WP
      DXP=DXP/WP
      PHASE=0.
      IF (PER.NE.0D0) PHASE=(TP-T0)/PER
C
C
      IF (KB.EQ.0) THEN
        IF (NCOL.EQ.3) THEN
          IF (ID.EQ.-1) THEN
            WRITE (OUT,1503) TP,PHASE,N,WP,(VP(J),RMS(J),J=1,3),
     *           VP(5),VP(6),XP,NOBS,KPOZOR
            ELSE
       IF(MSYS.NE.1)
     *  WRITE (OUT,1504) TP,PHASE,N,WP,(VP(J),RMS(J),J=1,3),            REL 9.1
     *           VP(5),VP(6),XP,DXP,NHKD,NOBS,KPOZOR
       IF(MSYS.EQ.1)                                                    REL.9.1
     *       WRITE (OUT,7504) TP,PHASE,N,WP,(VP(J),RMS(J),J=1,3),       REL 9.1
     *           VP(5),VP(6),XP,DXP,NHKD,NOBS,KPOZOR                    REL 9
            END IF
          ELSE
          IF (ID.EQ.-1) THEN
            WRITE (OUT,9503) TP,PHASE,N,WP,(VP(J),RMS(J),J=1,4),
     *           VP(5),VP(6),XP,NOBS,KPOZOR
            ELSE
C      IF(MSYS.NE.1) WRITE (OUT,9504) TP,PHASE,N,WP,(VP(J),RMS(J),J=1,4),REL 9
C     *           VP(5),VP(6),XP,DXP,NHKD,NOBS,KPOZOR                    REL 9
C      IF(MSYS.EQ.1)
       WRITE (OUT,8504) TP,PHASE,N,WP,(VP(J),RMS(J),J=1,4),             REL 9.1
     *           VP(5),VP(6),VP(7),XP,DXP,NHKD,NOBS,KPOZOR              REL 9.1
            END IF
          END IF
        ELSE
        IF (ID.EQ.-1) THEN
          WRITE (OUT,1507) TP,PHASE,N,WP,VP(KB),RMS(KB),XP,
     *           NOBS,KPOZOR
          ELSE
          WRITE (OUT,1508) TP,PHASE,N,WP,VP(KB),RMS(KB),XP,
     *           DXP,NHKD,NOBS,KPOZOR
          END IF
        END IF
C
  520 IF (J1.GT.NM4.OR.JD.GT.FO) GO TO 498
C
      IF (KLIC.EQ.6) GO TO 522
  521 T2=T2+P
      IF(HJD-T2) 523,521,521
  522 T2=HJD+P
  523 DO 524 J=NC1,NC2
      VP(J)=0.
  524 RMS(J)=0.
      TP=0D0
      XP=0.
      DXP=0.
      WP=0.
      N=0
      NHKD=KHD
      NQ=IQ
      NAP=IAP
      NCS=ICS
      NEX=IEX
      NOBS=IOBS
      NPOZOR=DAT(1)
      DO 525 J=1,3
  525 KPOZOR(J)=JPOZOR(J)
      GO TO 509
C
C
   97 WRITE (*,1991) INP
 1991 FORMAT (//5X,'Error - archive ',A12,' not sorted')
    1 RETURN 1
      END
